/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal.backend.impl;

import java.util.Arrays;

import edu.washington.cs.vanish.conf.VanishConfiguration;
import edu.washington.cs.vanish.internal.InvalidArgumentVanishException;
import edu.washington.cs.vanish.internal.backend.TooManySharesLostVanishException;
import edu.washington.cs.vanish.internal.backend.VanishBackendException;
import edu.washington.cs.vanish.logging.VanishLogger;
import junit.framework.TestCase;

public class OpenDHTVanishBackendTest extends TestCase {
	public void testPutGet() {
		OpenDHTVanishBackendImpl opendht = null;
		try {
			opendht =
				new OpenDHTVanishBackendImpl(new VanishConfiguration(),
						VanishLogger.getLogger("test"));
		} catch (InvalidArgumentVanishException e) {
			e.printStackTrace();
			fail();
		}
		
		try { opendht.init(); }
		catch (VanishBackendException e) {
			e.printStackTrace();
			fail();
		}
		
		System.out.println("Putting...");

		try {
			opendht.pushShares(new byte[][]{ "share1_new".getBytes(),
					                 "share1_new".getBytes() },
					   new byte[][]{ "location1".getBytes(),
					                 "location2".getBytes() });
		} catch (VanishBackendException e) {
			e.printStackTrace();
			fail();
		}
		
		System.out.println("Getting...");
		
		try {
			byte[][] shares = opendht.getShares(
					new byte[][]{ "location1".getBytes(),
					              "location2".getBytes() }, 1);
			assertEquals(2, shares.length);
			assertTrue(shares[0] != null || shares[1] != null);
			assertTrue(shares[0] == null ||
				   Arrays.equals("share1_new".getBytes(), shares[0]));
			assertTrue(shares[1] == null ||
				   Arrays.equals("share2_new".getBytes(), shares[1]));
		} catch (VanishBackendException e) {
			e.printStackTrace();
			fail();
		} catch (TooManySharesLostVanishException e) {
			e.printStackTrace();
			fail();
		}
	}
	
	/*
	public static void main(String args[]) {
		OpenDHTVanishBackendTest test = new OpenDHTVanishBackendTest();
		test.testPutGet();
	}
	*/
}
