/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.conf;

import java.io.File;
import java.net.URL;

import org.apache.commons.configuration.ConfigurationException;
import org.apache.commons.configuration.PropertiesConfiguration;

import edu.washington.cs.vanish.util.Constants;
/**
 * 
 * @author roxana
 *
 */
public class VanishConfiguration extends PropertiesConfiguration {
	public enum TimeUnit {
		SECONDS,
		MINUTES,
		HOURS,
		DAYS,
	}

	public VanishConfiguration() {
		super();
	}
	
	public VanishConfiguration(File file) throws ConfigurationException {
		super(file);
	}
	
	public VanishConfiguration(String config) throws ConfigurationException {
		super(config);
	}
	
	public VanishConfiguration(URL config) throws ConfigurationException {
		super(config);
	}
	
	public long getTimeInMillis(String name, int default_value, 
			                    TimeUnit unit) {
		return convertFromUnitToMillis(super.getInt(name, default_value),
				                       unit);
	}
	
	public long convertFromUnitToMillis(int value, TimeUnit unit) {
		switch (unit) {
		case SECONDS: return value * Constants.SECONDS;
		case MINUTES: return value * Constants.MINUTES;
		case HOURS:   return value * Constants.HOURS;
		case DAYS:    return value * Constants.DAYS;
		}
		return value;
	}
	
	@Override
	public Object clone() {
		return super.clone();
	}
	
	public String[] getStringArray(String key, String[] defaults) {
		String[] ret = super.getStringArray(key);
		if (ret == null || ret.length == 0) ret = defaults;
		return ret;
	}
}
