/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal;

import java.io.InputStream;
import java.io.OutputStream;

import edu.washington.cs.vanish.internal.impl.InputStreamWrapper;
import edu.washington.cs.vanish.internal.impl.OutputStreamWrapper;
import edu.washington.cs.vanish.internal.metadata.Metadata;
import edu.washington.cs.vanish.util.Immutable;
import edu.washington.cs.vanish.util.Initializable;
/**
 * Convenience interface for the Vanish core for the case when the metadata
 * is encapsulated inside the InputStream.
 * 
 * @author roxana
 */
public interface MetadataEncapsulatedVanishInternalInterface
extends Initializable {
	public void encapsulate(InputStream clear_data_is,
                            OutputStreamWrapper enc_data_os,
                            Metadata metadata)
	throws VanishException;
	
	public void encapsulateUsingPrepushedMetadata(InputStream clear_data_is,
            OutputStreamWrapper enc_data_os,
            @Immutable Metadata metadata)
	throws VanishException;

	/**
	 * 
	 * @param enc_data_is
	 * @param clear_data_os
	 * @return  metadata
	 * @throws MetadataEncapsulatedVanishException
	 */
	public Metadata decapsulate(InputStreamWrapper enc_data_is,
                                OutputStream clear_data_os)
    throws MetadataEncapsulatedVanishException, VanishException;

	/**
	 * 
	 * @param enc_data_is
	 * @param refreshed_enc_data_os
	 * @param new_metadata
	 * @return  old metadata
	 * @throws MetadataEncapsulatedVanishException 
	 */
    public Metadata refreshDeeply(InputStreamWrapper enc_data_is,
                                  OutputStreamWrapper refreshed_enc_data_os,
                                  Metadata new_metadata)
    throws MetadataEncapsulatedVanishException, VanishException;

    public void refreshReadOnly(@Immutable Metadata metadata)
    throws VanishException;
}
