/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal;

import java.io.InputStream;
import java.io.OutputStream;

import edu.washington.cs.vanish.internal.VanishException;
import edu.washington.cs.vanish.internal.impl.InputStreamWrapper;
import edu.washington.cs.vanish.internal.impl.OutputStreamWrapper;
import edu.washington.cs.vanish.internal.metadata.Metadata;
import edu.washington.cs.vanish.util.Immutable;
import edu.washington.cs.vanish.util.Initializable;
/**
 * 
 * @author roxana
 */
public interface VanishInternalInterface extends Initializable {	
	public void encapsulate(InputStream clear_data_is, 
			                OutputStreamWrapper enc_data_os,
			                Metadata metadata)
	throws VanishException;
	
	public void encapsulateUsingPrepushedMetadata(InputStream clear_data_is,
			OutputStreamWrapper enc_data_os,
			@Immutable Metadata metadata)
    throws VanishException;
	
	public void decapsulate(InputStreamWrapper enc_data_is,
			                OutputStream clear_data_os,
                            @Immutable Metadata metadata)
    throws VanishException;

	/**
	 * Refreshes a VDO object.
	 * Generates a new encryption/decryption key and sprinkles shares of
	 * it into the storage system.
	 * 
	 * @param enc_data_is
	 * @param refreshed_enc_data_os
	 * @param old_object_metadata
	 * @param new_object_metadata
	 * @throws VanishException
	 */
	public void refreshDeeply(InputStreamWrapper enc_data_is,
			                  OutputStreamWrapper refreshed_enc_data_os,
			                  @Immutable Metadata old_metadata,
			                  Metadata new_metadata)
	throws VanishException;
	
	/**
	 * Refreshes the same encryption/decryption key by sprinkling *new* shares
	 * of it into the storage system. <br>
	 * (Since it doesn't have as parameters the data input/output streams,
	 * it cannot modify the data, and so it cannot generate a new key.)
	 * 
	 * @param metadata
	 * @throws VanishException
	 */
	public void refreshReadOnly(@Immutable Metadata metadata)
    throws VanishException;
}
