/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal.crypto;

import java.io.InputStream;
import java.io.OutputStream;

import edu.washington.cs.vanish.internal.InvalidArgumentVanishException;
import edu.washington.cs.vanish.internal.VanishException;
import edu.washington.cs.vanish.internal.metadata.VDOParams;
import edu.washington.cs.vanish.util.Initializable;
/**
 * 
 * @author roxana
 */
public interface SymmetricEncDec extends Initializable {
	/**
	 * Must not make a copy of the key.
	 * @param clear_is
	 * @param key
	 * @return
	 * @throws VanishException
	 */
    public InputStream encrypt(InputStream clear_is, byte[] key,
    		VDOParams vdo_params)
    throws CryptoVanishException, InvalidArgumentVanishException;
    
    /**
     * Must not make a copy of the key.
     * @param clear_is
     * @param enc_os
     * @param key
     * @throws VanishException
     */
    public void encryptToOutputStream(InputStream clear_is,
    		                          OutputStream enc_os,
    		                          byte[] key,
    		                          VDOParams params)
    throws CryptoVanishException, InvalidArgumentVanishException;

    /**
     * Must not make a copy of the key.
     * @param enc_is
     * @param key
     * @return
     * @throws VanishException
     */
    public InputStream decrypt(InputStream enc_is, byte[] key,
    		                   VDOParams params)
    throws CryptoVanishException, InvalidArgumentVanishException;

    /**
     * Must not make a copy of the generated key.
     * @return
     * @throws VanishException
     */
    public byte[] generateKey(VDOParams params)
    throws CryptoVanishException, InvalidArgumentVanishException;
}