/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal.metadata;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.HashMap;
import java.util.Map;

/**
 * TODO(roxana): Define an annotation and check for it to prevent remote
 * people from overriding certain parameters of a class (Amit's idea). 
 * 
 * @author alevy
 */
public abstract class Mappable {
	public Map<String, Object> toMap() {
		Map<String, Object> result = new HashMap<String, Object>();
		for (Field f : this.getClass().getDeclaredFields()) {
			if (Modifier.isStatic(f.getModifiers())) {
				// Don't serialize static members, as they'll be rejected 
				// by de-serializer anyway for security reasons.
				continue;
			}
			boolean was_accessible = f.isAccessible();
			f.setAccessible(true);
			String name = f.getName();
			try {
				result.put(name, f.get(this));
			} catch (IllegalArgumentException e) {
				// Will never happen.
			} catch (IllegalAccessException e) {
				// Will never happen.
			}
			f.setAccessible(was_accessible);
		}
	
		return result;
	}
	
	public void setFromMap(Map<String, ? extends Object> map) {
		for (String field : map.keySet()) {
			try {
				Field f = this.getClass().getDeclaredField(field);
				if (f == null) continue;  // no such field -- ignore.
				if (Modifier.isStatic(f.getModifiers())) {
					// Refuse updates of class members for security reasons.
					continue;
				}

				boolean was_accessible = f.isAccessible();
				f.setAccessible(true);
				f.set(this, map.get(field));
				f.setAccessible(was_accessible);
			} catch (Exception e) {  // Ignore and continue.
				// e.printStackTrace();  // don't print anything.
			}
		}
	}
}