/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal.metadata.impl;

import java.util.Arrays;

import edu.washington.cs.vanish.internal.metadata.Metadata;
import edu.washington.cs.vanish.internal.metadata.VDOParams;

/**
 * 
 * @author roxana
 */
public class IndirectKeyMetadataImpl implements Metadata {
	private static final long serialVersionUID = 4210242816539566061L;
	
	private final Metadata metadata;
	private byte[] encrypted_data_key;
	
	public IndirectKeyMetadataImpl(VDOParams params,
			                       long location_seed) {
		this(new BasicMetadataImpl(params, location_seed));
	}
	
	/**
	 * @param metadata  encapsulated metadata; must not be null.
	 */
	public IndirectKeyMetadataImpl(Metadata metadata) {
		this.metadata = metadata;
		this.encrypted_data_key = null;
	}
	
	// Metadata interface:

	public VDOParams getVDOParams() {
		return (metadata == null ? null : metadata.getVDOParams());
	}

	public long[] getAllPossibleLocationSeeds() {
		return metadata.getAllPossibleLocationSeeds();
	}

	public long getLocationSeed() { return metadata.getLocationSeed(); }
	
	// Type-specific accessors:
	
	public byte[] getEncryptedDataKey() { return encrypted_data_key; }
	
	public void setEncryptedDataKey(byte[] encrypted_data_key) {
		this.encrypted_data_key = encrypted_data_key;
	}
	
	// Object functions:
	
	@Override
	public String toString() {
		return metadata.toString() + ", enc_data_key = " + encrypted_data_key;
	}
	
	@Override
	public boolean equals(Object other) {
		if (other == null) return false;
		if (this == other) return true;
		if (! (other instanceof IndirectKeyMetadataImpl)) return false;
		IndirectKeyMetadataImpl o = (IndirectKeyMetadataImpl)other;
		return metadata.equals(o) &&
		       (o.encrypted_data_key == this.encrypted_data_key ||
		    	(o.encrypted_data_key != null &&
		    	 this.encrypted_data_key != null &&
		         Arrays.equals(o.encrypted_data_key,
		        		       this.encrypted_data_key)));
	}
	
	@Override
	public int hashCode() {
		int hash = 7;
		hash = hash * 31 + metadata.hashCode();
		hash = hash * 31 + (encrypted_data_key == null 
		       ? 0 : Arrays.hashCode(encrypted_data_key));
		return hash;
	}
}
