/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.logging;

import org.apache.log4j.Logger;

import edu.washington.cs.vanish.internal.VanishException;
/**
 * 
 * @author roxana
 *
 */
public class VanishLogger {
	private final Logger logger;
	
	protected VanishLogger(String name) {
		logger = Logger.getLogger(name);
	}
	
	public void info(String msg) {
		logger.info(msg);
	}
	
	public void info(String msg, Throwable t) {
		logger.info(msg, t);
	}
	
	public LogStat logStat(final String msg) {
		logger.info(msg + " enter");
		return new LogStat() {
			private long enter_time = System.currentTimeMillis();
			// @Override
			public long end() {
				long runtime = System.currentTimeMillis() - enter_time;
				logger.info(
					msg + " exit (" + runtime + " ms)");
				return runtime;
			}
			// @Override
			public long end(VanishException e) {
				if (e == null) return end();
				long runtime = System.currentTimeMillis() - enter_time;
				logger.error(msg + " exit error (" + runtime + " ms)", e);
				return runtime;
			}
			// @Override
			public long elapsed() {
				return System.currentTimeMillis() - enter_time;
			}
		  };
	}
	
	public void debug(String msg) {
		logger.debug(msg);
	}
	
	public void warn(String msg) {
		logger.warn(msg);
	}
	
	public void debug(String msg, Throwable t) {
		logger.debug(msg, t);
	}
	
	public void error(String msg) {
		logger.error(msg);
	}
	
	public void error(String msg, Throwable t) {
		logger.error(msg, t);
	}
	
	public static VanishLogger getLogger(String name) {
		return new VanishLogger(name);
	}
	
	public boolean isDebugEnabled() { return logger.isDebugEnabled(); }
}
