/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.service.impl;

import edu.washington.cs.vanish.conf.VanishConfiguration;
import edu.washington.cs.vanish.internal.InvalidArgumentVanishException;
import edu.washington.cs.vanish.util.CmdLineParser;
import edu.washington.cs.vanish.util.Defaults;

/**
 * 
 * @author roxana
 */
public class VanishServerCmdLineParser extends CmdLineParser {
	
	public VanishServerCmdLineParser(VanishConfiguration conf) { super(conf); }
	
	@Override
	protected int parseOption(String arg, String args[], int i)
	throws InvalidArgumentVanishException {
		if (arg.equals("-s")) {  // Vanish XML-RPC server port.
            if (i < args.length) {
            	int vanish_port = -1;
            	try {
            		vanish_port = Integer.parseInt(args[i++]);
            	} catch (Exception e) {
            		throw new InvalidArgumentVanishException(
            				"-s requires an int port");
            	}
            	conf.setProperty(Defaults.CONF_VANISH_PORT, vanish_port);
            } else {
            	throw new InvalidArgumentVanishException(
            			"-s requires an int port");
            }
        } else if (arg.equals("-e")) {
        	String vanish_factory_class = null;
        	if (i < args.length) {
        		vanish_factory_class = args[i++];
            } else {
            	throw new InvalidArgumentVanishException(
            			"-e requires a class name");
            }
        	conf.setProperty(Defaults.CONF_VANISH_FACTORY_CLASS,
        			vanish_factory_class);
        } else {
        	throw new InvalidArgumentVanishException(
        			"Unknown option "+ arg + "(" +
        			this.getClass().getCanonicalName() +")");
        }
		
		return i;
	}

	public String usage() {
		return "java " + this.getClass().getName() +
			"\t[-s <Vanish service port> (default 10080)]\n" +
			"\t[-e <vanish factory class (default " +
			"edu.washington.cs.vanish.service.impl.DefaultVanishFactory);\n" +
			"\t\tclass must have a constructor with one VanishServerParams " +
			"constructor>]\n";
	}

	@Override
	public void validate() throws InvalidArgumentVanishException { }

	@Override
	protected void parseCommand(String command)
	throws InvalidArgumentVanishException {
		throw new InvalidArgumentVanishException("Invalid command" + command);
	}
}
