/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.system.impl;

import edu.washington.cs.vanish.internal.VanishException;
import edu.washington.cs.vanish.internal.metadata.Metadata;
import edu.washington.cs.vanish.system.VanishInterface;
import edu.washington.cs.vanish.system.VanishRefreshTask;

/**
 * 
 * @author roxana
 */
public class ReadOnlyVanishRefreshTask extends VanishRefreshTask {
	private static final long serialVersionUID = 784699826073047645L;

	private Metadata metadata;
	
	public ReadOnlyVanishRefreshTask(VanishInterface vanish_system_ptr,
			Metadata metadata,
			long creation_date, long timeout_date, long refresh_interval) {
		super(vanish_system_ptr, creation_date, timeout_date,
			  refresh_interval);
		this.metadata = metadata;
	}

	@Override
	protected void refresh(VanishInterface vanish_system) {
		try { vanish_system.refreshReadOnly(metadata); }
		catch (VanishException e) { e.printStackTrace(); }  // TODO: handle?
	}
	
	/**
	 * Used for testing mostly. Please DO NOT to use.
	 * @return
	 */
	@Deprecated
	public Metadata getMetadata() { return metadata; }
	
	// Object functions:
	
	@Override
	public boolean equals(Object other) {
		if (this == other) return true;
		if (other == null) return false;
		if (! (other instanceof ReadOnlyVanishRefreshTask)) return false;
		ReadOnlyVanishRefreshTask o = (ReadOnlyVanishRefreshTask)other;
		if (this.metadata == null && o.metadata != null) return false;
		if (! this.metadata.equals(o.metadata)) return false;
		return super.equals(other);
	} 
	
	@Override
	public int hashCode() {
		int hash = 7;
		hash = hash * 31 + (metadata == null ? 0 : metadata.hashCode());
		hash = hash * 31 + super.hashCode();
		return hash;
	}
}
