/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.util;

import org.apache.commons.configuration.Configuration;

import edu.washington.cs.vanish.internal.InvalidArgumentVanishException;

/**
 * 
 * @author roxana
 */
public abstract class CmdLineParser {
	protected Configuration conf;
	
	public CmdLineParser(Configuration conf) { this.conf = conf; }
	
	public CmdLineParser() { }
	
	public boolean parse(String[] args) {
		try {
			parseHelper(args);
		} catch (InvalidArgumentVanishException e) {
			System.err.println(e.getMessage());
			System.err.println(usage());
			return false;
		}
		return true;
	}
	
	private void parseHelper(String args[])
	throws InvalidArgumentVanishException {
		int i = 0;
        while (i < args.length && args[i].startsWith("-")) {
            String arg = args[i++];
            try {
            	i = parseOption(arg, args, i);
            } catch (InvalidArgumentVanishException e) {
            	System.err.println(e.getMessage());
            	System.err.println(usage());
            	break;
            }   
        }
        if (i < args.length) parseCommand(args[i]);

		validate();
	}
	
	protected abstract void parseCommand(String command)
	throws InvalidArgumentVanishException;
	
	protected abstract int parseOption(String option, String[] other_args,
			int arg_index)
	throws InvalidArgumentVanishException;	
	
	public abstract String usage();
	
	public abstract void validate() throws InvalidArgumentVanishException;
}
