/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.util;

import edu.washington.cs.vanish.conf.VanishConfiguration;
import edu.washington.cs.vanish.service.impl.DefaultVanishFactory;
import edu.washington.cs.vanish.service.impl.VanishServiceHandler;
import edu.washington.cs.vanish.stats.StatsCollector;
/**
 * 
 * @author roxana
 *
 */
public interface Defaults {
	public static final String VANISH_CONFIGURATION_FILE = "vanish.properties";
	
	/**
	 * TODO(roxana): Minimize the usage of this member.
	 */
	@Deprecated
	public static final VanishConfiguration CONF =
		VanishUtils.getConfig(VANISH_CONFIGURATION_FILE);
	
	public static final String CONF_VANISH_BACKEND_IMPL_CLASS =
		"vanish.internal.backends";
	public static final String[] CONF_VANISH_BACKEND_IMPL_CLASS_DEFAULT =
		new String[] {
			"vuze: edu.washington.cs.vanish.internal.backend.rpcimpl.RPCVanishBackendImpl",
			"opendht: edu.washington.cs.vanish.internal.backend.impl.OpenDHTVanishBackendImpl"
		};
	
	// Crypto:
	
	public static final String CONF_VANISH_CRYPTO_RANDOMGENERATOR =
		"vanish.internal.crypto.randomgenerator";
	public static final String CONF_VANISH_CRYPTO_RANDOMGENERATOR_DEFAULT =
		"SHA1PRNG";
	
	public static final String CONF_VANISH_CRYPTO_ENCKEYLENGTH_BITS =
		"vanish.internal.crypto.enckeylength_bits";
	public static final int CONF_VANISH_CRYPTO_ENCKEYLENGTH_BITS_DEFAULT =
		128;
	
	public static final String CONF_VANISH_CRYPTO_ENCMODE =
		"vanish.internal.crypto.encmode";
	public static final String CONF_VANISH_CRYPTO_ENCMODE_DEFAULT = "CBC";

	public static final String CONF_VANISH_CRYPTO_ENCALGORITHM =
		"vanish.internal.crypto.encalgorithm";
	public static final String CONF_VANISH_CRYPTO_ENCALGORITHM_DEFAULT = "AES";
	
	
	// VDO:
	
	public static final String CONF_VANISH_VDO_DEFAULTNUMSHARES =
		"vanish.internal.vdo.defaultnumshares";
	public static final int CONF_VANISH_VDO_DEFAULTNUMSHARES_DEFAULT = 10;
	
	public static final String CONF_VANISH_VDO_DEFAULTTHRESHOLD =
		"vanish.internal.vdo.defaultthreshold";
	public static final int CONF_VANISH_VDO_DEFAULTTHRESHOLD_DEFAULT = 7;
	
	public static final String CONF_VANISH_VDO_DEFAULTTIMEOUT_H =
		"vanish.internal.vdo.defaulttimeout_h";
	public static final int CONF_VANISH_VDO_DEFAULTTIMEOUT_H_DEFAULT = 8;
	
	public static final String CONF_VANISH_VDO_DEFAULTNETWORKS =
		"vanish.internal.vdo.defaultnetworks";
	public static final String[] CONF_VANISH_VDO_DEFAULTNETWORKS_DEFAULT =
		new String[] { "vuze", "opendht" };
	
	// IO:
	public static final String CONF_VANISH_IO_MEMBUFFERSIZE =
		"vanish.internal.io.membuffersize";
	public static final int CONF_VANISH_IO_MEMBUFFERSIZE_DEFAULT = 4096;

	
	// Vanish core:
	
	public static final String CONF_VANISH_SYSTEM_REFRESH_SLACKTIME_MIN =
		"vanish.system.refresh.slacktime_min";
	public static final int CONF_VANISH_SYSTEM_REFRESH_SLACKTIME_MIN_DEFAULT =
		15;
	
	public static final String CONF_VANISH_SYSTEM_REFRESH_PERIOD_H =
		"vanish.system.refresh.period_h";
	public static final int CONF_VANISH_SYSTEM_REFRESH_PERIOD_H_DEFAULT = 8;
	
	public static final String CONF_VANISH_SYSTEM_REFRESH_SAVESTATE_MIN =
		"vanish.system.refresh.savestateperiod_min";
	public static final int CONF_VANISH_SYSTEM_REFRESH_SAVESTATE_MIN_DEFAULT =
		10;
	
	public static final String CONF_VANISH_SYSTEM_PREPUSH_PERIOD_MIN =
		"vanish.system.prepush.period_min";
	public static final int CONF_VANISH_SYSTEM_PREPUSH_PERIOD_MIN_DEFAULT = 15;
	
	public static final String
		CONF_VANISH_SYSTEM_PREPUSH_SHOULD_ONLY_USE_PREPUSH =
			"vanish.system.prepush.encapsulate_only_using_prepushed";
	public static final boolean
		CONF_VANISH_SYSTEM_PREPUSH_SHOULD_ONLY_USE_PREPUSH_DEFAULT = false;
	
	public static final String CONF_VANISH_SYSTEM_PREPUSH_NUMVDOS =
		"vanish.system.prepush.numvdos";
	public static final int CONF_VANISH_SYSTEM_PREPUSH_NUMVDOS_DEFAULT = 4;
	
	public static final String CONF_VANISH_SYSTEM_PREPUSH_THESHOLD =
		"vanish.system.prepush.threshold";
	public static final int CONF_VANISH_SYSTEM_PREPUSH_THESHOLD_DEFAULT = 2;
	
	public static final String CONF_VANISH_SYSTEM_STORAGE_DIR =
		"vanish.system.storagedir";
	public static final String CONF_VANISH_SYSTEM_STORAGE_DIR_DEFAULT =
		FileUtil.getPath(FileUtil.kTmpDir, "vanish"); 
	
	// Vanish service:
	
	public static final String CONF_VANISH_PORT = "vanish.service.port";
	public static final int CONF_VANISH_PORT_DEFAULT = 10080;

	public static final String CONF_VANISH_BIND_TO_LOCALHOST =
		"vanish.service.bindtolocalhost";
	public static final boolean CONF_VANISH_BIND_TO_LOCALHOST_DEFAULT = true;
	
	public static final String CONF_VANISH_FACTORY_CLASS =
		"vanish.service.vanishfactoryclass";
	public static final String CONF_VANISH_FACTORY_CLASS_DEFAULT =
		DefaultVanishFactory.class.getName();

	public static final String CONF_VANISH_SERVICE_NUM_THREADS =
		"vanish.service.threads";
	public static final int CONF_VANISH_SERVICE_NUM_THREADS_DEFAULT = 20;
	
	public static final String CONF_VANISH_SERVICE_REMOTE_MAXFILESIZE_KB =
		"vanish.service.remote.maxfilesize_kb";
	public static final long
	CONF_VANISH_SERVICE_REMOTE_MAXFILESIZE_KB_DEFAULT = 10240;
	
	public static final String CONF_VANISH_SERVICE_SHOULD_GZIP =
		"vanish.service.shouldgzip";
	public static final boolean CONF_VANISH_SERVICE_SHOULD_GZIP_DEFAULT = false;
	
	public static final String CONF_VANISH_SERVICE_HANDLER_CLASS =
		"vanish.service.handler_class";
	public static final String CONF_VANISH_SERVICE_HANDLER_CLASS_DEFAULT = 
		VanishServiceHandler.class.getName();
	
	
	// Stats:
	
	public static final String CONF_VANISH_STATS_ENABLED =
		"vanish.service.stats.level";
	public static final String CONF_VANISH_STATS_ENABLED_DEFAULT =
		StatsCollector.ReportLevel.SENSITIVE.name();
	
	public static final String CONF_VANISH_STATS_SAVEINTERVAL_M =
		"vanish.service.stats.saveinterval_min";
	public static final int CONF_VANISH_STATS_SAVEINTERVAL_M_DEFAULT = 5;
	
	public static final String CONF_VANISH_STATS_BULK_UPLOAD_SIZE =
		"vanish.service.stats.bulkupload_bytes";
	public static final int CONF_VANISH_STATS_BULK_UPLOAD_SIZE_DEFAULT = 1024;
	
	public static final String CONF_VANISH_STATS_SHOULDGZIP =
		"vanish.service.stats.shouldgzip";
	public static final boolean CONF_VANISH_STATS_SHOULDGZIP_DEFAULT =
		false;
	
	public static final String CONF_VANISH_STATS_SAVEURL =
		"vanish.service.stats.statcollectorurl";
	public static final String CONF_VANISH_STATS_SAVEURL_DEFAULT =
		"http://vanish-admin.appspot.com/storestat";
	
	public static final String CONF_VANISH_STATS_SAVETIMEOUT =
		"vanish.service.stats.uploadtimeout_s";
	public static final int CONF_VANISH_STATS_SAVETIMEOUT_DEFAULT = 15;
}
