/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.util;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.lang.management.ManagementFactory;
import java.lang.management.OperatingSystemMXBean;

/**
 * TODO(roxana): Move this to its own package (vanish.io).
 * @author roxana
 */
public class FileUtil {
	@SuppressWarnings("deprecation")
	public static final int kIOBufferSize = Defaults.CONF.getInt(
			Defaults.CONF_VANISH_IO_MEMBUFFERSIZE,
			Defaults.CONF_VANISH_IO_MEMBUFFERSIZE_DEFAULT);
	
	public enum OsType {
		WIN,
		LIN,
		MAC,
	};
	
	public static final OsType kOSType = getOS();
	
	public static final String kTmpDir = getTmpDir();
	
	public static void writeInputOutput(InputStream is, OutputStream os)
	throws IOVanishException {
		// Write data from input to the output stream.
		byte[] buffer = new byte[kIOBufferSize];
		try {
			int n = is.read(buffer);
			while (n >= 0) {
				os.write(buffer, 0, n);
				n = is.read(buffer);
			}
		} catch (IOException e) {
			throw new IOVanishException("Failed to access I/O stream", e);
		}
	}

	public static void deleteDir(File dir) throws IOVanishException {
        if (dir.isDirectory()) {
            String[] children = dir.list();
            for (int i=0; i<children.length; i++) {
                deleteDir(new File(dir, children[i]));
            }
        }
    
        // The directory is now empty so delete it
        if (! dir.delete()) {
        	throw new IOVanishException("Failed to delete directory " + dir);
        }
    }

	private static String getTmpDir() {
		String tmpdir = System.getProperty("java.io.tmpdir");
		if (tmpdir == null) {
			if (kOSType == OsType.WIN) tmpdir = "C:\\Temp";
			else tmpdir = "/tmp";
		}
		return tmpdir;
	}

	public static String getPath(String ... parts) {
		StringBuilder path = new StringBuilder("");
		int i = 0;
		for (String p: parts) {
			path.append(p);
			if (++i < parts.length) {
				path.append(System.getProperty("file.separator"));
			}
		}
		return path.toString();
	}
	
	public static File generateTmpFile() {
		return generateTmpFile("vanish", "" + System.currentTimeMillis());
	}
	
	public static File generateTmpFile(String... name_parts) {
		return generateTmpFile(getPath(name_parts));
	}
	
	public static File generateTmpFile(String filename) {
		File f = new File(getPath(kTmpDir, filename));
		if (!f.getParentFile().exists()) f.getParentFile().mkdirs();
		return f;
	}

	// TODO(roxana): Plug in correct names for windows and mac.
	private static OsType getOS() {
		OperatingSystemMXBean os =
			ManagementFactory.getOperatingSystemMXBean();
		String os_name = os.getName();
	    if (os_name.equalsIgnoreCase("windows")) return OsType.WIN;
	    else if (os_name.equalsIgnoreCase("mac")) return OsType.MAC;
	    else return OsType.LIN;  // call it some flavor of linux.
	}
}
