/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.util;

import java.util.TimerTask;
import java.util.concurrent.atomic.AtomicInteger;
/**
 * 
 * @author roxana
 *
 */
public abstract class LimitedRunsTimerTask extends TimerTask {
	// There's no concurrency Timer, so we don't need synchronization.
	AtomicInteger num_executions_left;
	
	/**
	 * Constructor.
	 * @param num_node_events number of executions of this task, if > 0.
	 *                        If <= 0, the task isn't executed.
	 */
	public LimitedRunsTimerTask(int num_executions) {
		this.num_executions_left = new AtomicInteger(num_executions);
	}
		
	@Override
	public synchronized final void run() {
		if (num_executions_left.getAndDecrement() <= 0) {
			// This task should no longer execute.
			this.cancel();
			return;
		}
		
		runTask();
		
		if (num_executions_left.get() <= 0) {
			// This task should no longer execute.
			this.cancel();
			return;
		}
	}
		
	protected abstract void runTask();
}
