/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;

import edu.washington.cs.vanish.internal.VanishException;
import edu.washington.cs.vanish.internal.backend.TooManySharesLostVanishException;
import edu.washington.cs.vanish.internal.backend.VanishBackendInterface;
import edu.washington.cs.vanish.internal.backend.VanishBackendException;
import edu.washington.cs.vanish.stats.VanishStats;
/**
 * 
 * @author levya
 *
 */
public class MockVanishBackend implements VanishBackendInterface {
	private static Map<String, byte[]> storage;
	private boolean is_initialized;
	
	public MockVanishBackend() {
		storage = Collections.synchronizedMap(new HashMap<String, byte[]>());
	}

	// VanishBackend interface:

	public byte[] getID() { return null; }

	public byte[][] getShares(byte[][] indexes, int needed_keys)
	throws TooManySharesLostVanishException, VanishBackendException {
		byte[][] shares = new byte[indexes.length][];
		int i = 0;
		int num_retrieved_shares = 0;
		for (byte[] index: indexes) {
			String index_str = new String(index);
			byte[] share =  storage.get(index_str);
			shares[i++] = share;
			if (share != null) ++num_retrieved_shares;
		}
		if (num_retrieved_shares < needed_keys) {
			throw new TooManySharesLostVanishException("Got " +
					num_retrieved_shares + "/" + needed_keys + " shares");
		}
		return shares;
	}

	public VanishStats getStats() { return null; }  // TODO(roxana): Impl mock.

	public void init() throws VanishBackendException {
		this.is_initialized = true;
	}

	public void pushShares(byte[][] shares, byte[][] locations)
	throws VanishBackendException {
		int i = 0;
		for (byte[] index: locations) {
			storage.put(new String(index), shares[i++]);
		}
	}

	public byte[] generateLocation(Random prg) {
		return generateLocationRandomly(prg);
	}
	
	private static byte[] generateLocationRandomly(Random prg) {
		String s = "k" + prg.nextInt();
		return s.getBytes();
	}
	
	public static Map<String, byte[]> getAllMappings() { return storage; }
	
	public static void loseShares(long seed, int how_many) {
		Random prg = new Random(seed);
		assert(how_many <= storage.size());
		String to_delete[] = new String[how_many];
		for (int i = 0; i < how_many; ++i) {
			byte[] location = generateLocationRandomly(prg);
			to_delete[i] = new String(location);
		}
		
		for (String index: to_delete) storage.remove(index);
	}

	public boolean isInitialized() { return is_initialized; }

	public void stop() throws VanishException { }

	public String getIdentifier() {
		return "test";
	}
}
