/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal.impl;

import java.io.InputStream;
import java.io.OutputStream;
import java.security.SecureRandom;
import java.util.HashMap;
import java.util.Map;

import edu.washington.cs.vanish.conf.VanishConfiguration;
import edu.washington.cs.vanish.internal.AbstractTestForVanishInternal;
import edu.washington.cs.vanish.internal.InvalidArgumentVanishException;
import edu.washington.cs.vanish.internal.MockVanishBackend;
import edu.washington.cs.vanish.internal.backend.VanishBackendInterface;
import edu.washington.cs.vanish.internal.crypto.impl.ShamirSecretSharing;
import edu.washington.cs.vanish.internal.crypto.impl.SymmetricEncDecImpl;
import edu.washington.cs.vanish.internal.impl.BasicVanishImpl;
import edu.washington.cs.vanish.internal.metadata.VDOParams;
import edu.washington.cs.vanish.internal.metadata.impl.BasicMetadataImpl;
import edu.washington.cs.vanish.logging.VanishLogger;
/**
 * 
 * @author roxana
 *
 */
public class BasicVanishTest
extends AbstractTestForVanishInternal<BasicVanishImpl, BasicMetadataImpl> {
	private static final Map<String, VanishBackendInterface> kMockBackends =
		new HashMap<String, VanishBackendInterface>();
	static {
		kMockBackends.put("test", new MockVanishBackend());
	}
	
	public BasicVanishTest() throws Exception {
		this(new BasicVanishImpl(
				kMockBackends,
				new SymmetricEncDecImpl(new SecureRandom(),
						                new VanishConfiguration(),
						                VanishLogger.getLogger("test")),
				new ShamirSecretSharing(new SecureRandom(),
						new VanishConfiguration(),
		                VanishLogger.getLogger("test")),
				VanishLogger.getLogger("test")));
	}
	
	protected BasicVanishTest(BasicVanishImpl vanish) { super(vanish); }

	// AbstractTestForVanish functions:

	@Override
	protected void checkPutOutcome(BasicMetadataImpl object_metadata,
			                       String value,
			                       byte[] enc_data) { }

	@Override
	protected void checkRefreshOutcome(BasicMetadataImpl old_object_metadata,
			                           BasicMetadataImpl new_object_metadata,
			                           byte[] refreshed_enc_data_can_be_null) {
		
	}

	@Override
	protected BasicMetadataImpl instantiateMetadata(
			@SuppressWarnings("unused") BasicMetadataImpl metadata,
			long location_seed,
			int num_shares,
			int share_threshold)
	throws InvalidArgumentVanishException {
		return new BasicMetadataImpl(
				new VDOParams(num_shares, share_threshold,
						      VDOParams.kDefaultTimeout_h,
						      VDOParams.kEncryptionAlgo,
						      VDOParams.kEncryptionKeyLength,
						      VDOParams.kEncryptionMode,
						      new String[] {"test"}),
				location_seed);
	}
	
	@Override
	protected InputStreamWrapper wrapInputStream(InputStream is) {
		return new InputStreamWrapper(is); }

	@Override
	protected OutputStreamWrapper wrapOutputStream(OutputStream os) {
		return new OutputStreamWrapper(os);
	}
}
