/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal.impl;

import java.io.InputStream;
import java.io.OutputStream;
import java.security.SecureRandom;
import java.util.HashMap;
import java.util.Map;

import edu.washington.cs.vanish.conf.VanishConfiguration;
import edu.washington.cs.vanish.internal.AbstractTestForVanishInternal;
import edu.washington.cs.vanish.internal.InvalidArgumentVanishException;
import edu.washington.cs.vanish.internal.MockVanishBackend;
import edu.washington.cs.vanish.internal.backend.VanishBackendInterface;
import edu.washington.cs.vanish.internal.crypto.impl.ShamirSecretSharing;
import edu.washington.cs.vanish.internal.crypto.impl.SymmetricEncDecImpl;
import edu.washington.cs.vanish.internal.impl.BasicVanishImpl;
import edu.washington.cs.vanish.internal.impl.IndirectKeyVanishImpl;
import edu.washington.cs.vanish.internal.metadata.VDOParams;
import edu.washington.cs.vanish.internal.metadata.impl.IndirectKeyMetadataImpl;
import edu.washington.cs.vanish.logging.VanishLogger;
/**
 * 
 * @author roxana
 *
 */
public class IndirectKeyVanishTest
extends AbstractTestForVanishInternal<BasicVanishImpl, IndirectKeyMetadataImpl> {
	private static final Map<String, VanishBackendInterface> kMockBackends =
		new HashMap<String, VanishBackendInterface>();
	static {
		kMockBackends.put("test", new MockVanishBackend());
	}
	
	
	public IndirectKeyVanishTest() throws Exception {
		super(new IndirectKeyVanishImpl(kMockBackends,
					new SymmetricEncDecImpl(new SecureRandom(),
							new VanishConfiguration(),
							VanishLogger.getLogger("test")),
					new ShamirSecretSharing(new SecureRandom(),
							new VanishConfiguration(),
					        VanishLogger.getLogger("test")),
				    VanishLogger.getLogger("test")));
	}

	// AbstractTestForVanish functions:

	@Override
	protected void checkPutOutcome(IndirectKeyMetadataImpl object_metadata,
			                       String value,
			                       byte[] enc_data) {
		assertNotNull(object_metadata.getEncryptedDataKey());
	}

	@Override
	protected void checkRefreshOutcome(
			IndirectKeyMetadataImpl old_object_metadata,
			IndirectKeyMetadataImpl new_object_metadata,
			byte[] refreshed_enc_data_can_be_null) {
		assertNotNull(old_object_metadata.getEncryptedDataKey());
		if (new_object_metadata != null) {
			assertNotNull(new_object_metadata.getEncryptedDataKey());
		}
	}

	@Override
	protected IndirectKeyMetadataImpl instantiateMetadata(
			IndirectKeyMetadataImpl other,
			long location_seed,
			int num_shares,
			int share_threshold)
	throws InvalidArgumentVanishException {
		IndirectKeyMetadataImpl meta = new IndirectKeyMetadataImpl(
				new VDOParams(num_shares, share_threshold,
					      VDOParams.kDefaultTimeout_h,
					      VDOParams.kEncryptionAlgo,
					      VDOParams.kEncryptionKeyLength,
					      VDOParams.kEncryptionMode,
					      new String[] {"test"}),
				location_seed);
		if (other != null) {
			meta.setEncryptedDataKey(other.getEncryptedDataKey());
		}
		return meta;
	}

	@Override
	protected InputStreamWrapper wrapInputStream(InputStream is) {
		return new InputStreamWrapper(is);
	}

	@Override
	protected OutputStreamWrapper wrapOutputStream(OutputStream os) {
		return new OutputStreamWrapper(os);
	}
}
