/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.internal.metadata;

import java.util.HashMap;
import java.util.Map;

import junit.framework.TestCase;

import org.junit.Test;

/**
 * @author alevy
 * 
 */
public class MappableTest extends TestCase {

	@Test
	public void testToMap() {
		MockMappable mappable = new MockMappable();
		mappable.foo = 5;
		mappable.bar = 500L;
		mappable.baz = "Testing";

		Map<String, Object> map = mappable.toMap();
		assertEquals(5, map.get("foo"));
		assertEquals(500L, map.get("bar"));
		assertEquals("Testing", map.get("baz"));
		assertNull(map.get("bing"));
	}

	@Test
	public void testSetFromMap() {
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("foo", 123);
		map.put("bar", 444L);
		map.put("baz", "Wazzup?");
		map.put("bing", 17);

		MockMappable mappable = new MockMappable();
		mappable.setFromMap(map);

		assertEquals(123, mappable.foo);
		assertEquals(444L, mappable.bar);
		assertEquals("Wazzup?", mappable.baz);
		assertEquals(1024, MockMappable.bing);
	}

	/*
	 * Tests the behavior when an argument in the map is of the wrong type (e.g.
	 * String instead of int).
	 */
	@Test
	public void testSetFromMapWrongType() {
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("foo", "Woops");
		map.put("bar", 444L);

		MockMappable mappable = new MockMappable();
		mappable.foo = 4;
		mappable.setFromMap(map);

		// Test that variable assignment was ignored.
		assertEquals(4, mappable.foo);
		assertEquals(444L, mappable.bar);
	}

	private static class MockMappable extends Mappable {
		private int foo;
		private long bar;
		private String baz;
		public static int bing = 1024;
	}

}
