/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

package edu.washington.cs.vanish.stats.impl;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintStream;

import edu.washington.cs.vanish.conf.VanishConfiguration;
import edu.washington.cs.vanish.internal.InvalidArgumentVanishException;
import edu.washington.cs.vanish.logging.VanishLogger;
import edu.washington.cs.vanish.util.Defaults;
import edu.washington.cs.vanish.util.FileUtil;
import edu.washington.cs.vanish.util.IOVanishException;
import junit.framework.TestCase;

/**
 * Prerequisite: Appengine's running on the local machine.
 * @author roxana
 *
 */
public class StatUploaderImplTestSpecial extends TestCase {
	protected StatUploaderImpl uploader;
	
	protected void setUp() {
		VanishConfiguration conf = new VanishConfiguration();
		conf.setProperty(Defaults.CONF_VANISH_STATS_SAVEURL,
				         "http://localhost:8080/storestat");
		try {
			uploader = new StatUploaderImpl(conf,
					VanishLogger.getLogger("test"));
		} catch (InvalidArgumentVanishException e) {
			e.printStackTrace();
			fail("Failed to initialize uploader");
		}
	}
	
	protected void tearDown() { }
	
	public void testAnUploadWithTwoElements() {
		File tmp_file = generateLogFile(2);
		try {
			uploader.upload(tmp_file);
		} catch (IOVanishException e) {
			e.printStackTrace();
			fail("Failed to upload to server -- appengine server isn't up?");
		}
		//tmp_file.delete();
	}
	
	private File generateLogFile(int num_entries) {
		File tmp_file = FileUtil.generateTmpFile();
		PrintStream ps = null;
		try {
			ps = new PrintStream(new FileOutputStream(tmp_file));
		} catch (FileNotFoundException e1) {
			e1.printStackTrace();
			ps.close();
			tmp_file.delete();
			fail("Failed to open outputstream for tmp file");
		}
		for (int i = 0; i < num_entries; ++i) {
			ps.println("ts=" + i +
				";vdo_shares=10;op_time_ms=5817;op=decapsulate;" +
				"vdo_age_min=168;vid=3720465049504658664;vdo_timeout_h=8;" +
				"vdo_threshold=7;op_referrer=shell;vdo_id=90303672846364154"); 
		}
		ps.close();
		return tmp_file;
	}
	
	public static void main() {
		StatUploaderImplTestSpecial test =
			new StatUploaderImplTestSpecial();
		test.testAnUploadWithTwoElements();
	}
}
