/*
 * This code is subject to an academic license contained in the LICENSE-vanish.txt
 * file that can be found in the root directory of Vanish.
 */

/**
 * 
 */
package edu.washington.cs.vanish.system.impl;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;

import edu.washington.cs.vanish.internal.VanishException;
import edu.washington.cs.vanish.internal.impl.InputStreamWrapper;
import edu.washington.cs.vanish.internal.impl.OutputStreamWrapper;
import edu.washington.cs.vanish.internal.metadata.Metadata;
import edu.washington.cs.vanish.internal.metadata.VDOParams;
import edu.washington.cs.vanish.internal.metadata.impl.BasicMetadataImpl;
import edu.washington.cs.vanish.system.VanishInterface;
import edu.washington.cs.vanish.util.Constants;
import edu.washington.cs.vanish.util.FileUtil;

/**
 * Mock implementation of {@link VanishInterface}. Just appends a String to the
 * end of the message to simpulate encapsulation
 * 
 * @author alevy
 */
public class VanishMockImpl implements VanishInterface {

	public static final String ENCRYPTION_STRING = "This data is encrypted. You know because I just said so.";
	//public static final long HOUR_IN_MILLIS = 3600000;

	protected Map<Long, Long> seedTtls = new HashMap<Long, Long>();

	public Metadata decapsulate(InputStreamWrapper enc_data_is,
			OutputStream clear_data_os) throws VanishException {
		try {
			Metadata metadata = (Metadata) enc_data_is.getObjectInputStream()
					.readObject();
			long ttl = seedTtls.get(metadata.getLocationSeed());
			if (System.currentTimeMillis() > metadata.getLocationSeed()
					+ ttl) {
				throw new VanishException("Could not decrypt message");
			}
			
			for (int i = 0; i < ENCRYPTION_STRING.length(); ++i) {
				enc_data_is.read();
			}

			FileUtil.writeInputOutput(enc_data_is, clear_data_os);
			return metadata;
		} catch (IOException e) {
			throw new VanishException(e.getMessage());
		} catch (ClassNotFoundException e) {
			throw new VanishException(e.getMessage());
		}
	}

	public Metadata encapsulate(InputStream clear_data_is,
			OutputStreamWrapper enc_data_os, VDOParams params)
	throws VanishException {
		Metadata metadata = new BasicMetadataImpl(params,
				System.currentTimeMillis());
		seedTtls.put(metadata.getLocationSeed(),
				     params.getTimeout() * Constants.HOURS);
		try {
			ByteArrayOutputStream buf = new ByteArrayOutputStream();
			FileUtil.writeInputOutput(clear_data_is, buf);
			enc_data_os.getObjectOutputStream().writeObject(metadata);
			enc_data_os.write((ENCRYPTION_STRING + buf.toString()).getBytes());
		} catch (IOException e) {
			throw new VanishException(e.getMessage());
		}
		return metadata;
	}

	public Metadata refreshDeeply(InputStreamWrapper enc_data_is,
			OutputStreamWrapper refreshed_enc_data_os,
			VDOParams params)
	throws VanishException {
		try {
			enc_data_is.getObjectInputStream().readObject();
			Metadata newMetadata = new BasicMetadataImpl(params,
					System.currentTimeMillis());
			seedTtls.put(newMetadata.getLocationSeed(),
					params.getTimeout() * Constants.HOURS);
			refreshed_enc_data_os.getObjectOutputStream().writeObject(
					newMetadata);
			FileUtil.writeInputOutput(enc_data_is, refreshed_enc_data_os);
			return newMetadata;
		} catch (IOException e) {
			throw new VanishException(e.getMessage());
		} catch (ClassNotFoundException e) {
			throw new VanishException(e.getMessage());
		}
	}

	public void refreshReadOnly(Metadata metadata) throws VanishException {
		seedTtls.put(metadata.getLocationSeed(),
				     metadata.getVDOParams().getTimeout() * Constants.HOURS);
	}

	public void init() throws VanishException { }

	public boolean isInitialized() { return true; }

	public void stop() throws VanishException { }

}
